==> r-antd-0.2.1.tgz: package/es/r-form/r-form.js <==
import _slicedToArray from "babel-runtime/helpers/slicedToArray";
import _typeof from "babel-runtime/helpers/typeof";
import _extends from "babel-runtime/helpers/extends";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
var __rest = this && this.__rest || function (s, e) {
    var t = {};
    for (var p in s) {
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
    }if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
        if (e.indexOf(p[i]) < 0) t[p[i]] = s[p[i]];
    }return t;
};
import React, { Component } from "react";
import classNames from "classnames";
import omit from "lodash.omit";
import { Row, Col, Form, Button } from "antd";
var FormItem = Form.Item;

export var RForm = function (_Component) {
    _inherits(RForm, _Component);

    function RForm(props) {
        _classCallCheck(this, RForm);

        var _this = _possibleConstructorReturn(this, (RForm.__proto__ || Object.getPrototypeOf(RForm)).call(this, props));

        _this.onPreClear = function () {
            var _this$props = _this.props,
                form = _this$props.form,
                _this$props$footer = _this$props.footer,
                footer = _this$props$footer === undefined ? {} : _this$props$footer;
            var resetFields = form.resetFields;

            resetFields();
            var onClear = footer.onClear;

            if (typeof onClear != "function") return;
            onClear();
        };
        _this.renderHeader = function () {
            var header = _this.props.header;

            if (!header) return null;
            return React.createElement(
                Row,
                { style: { marginBottom: 24 } },
                React.createElement(
                    Col,
                    { span: 24 },
                    header
                )
            );
        };
        _this.renderFormItems = function () {
            var _this$props2 = _this.props,
                form = _this$props2.form,
                formItems = _this$props2.formItems,
                _this$props2$layout = _this$props2.layout,
                layout = _this$props2$layout === undefined ? "horizontal" : _this$props2$layout;
            var getFieldDecorator = form.getFieldDecorator;
            var renderCount = _this.state.renderCount;

            var DEFAULT_FORMITEM_LAYOUT = {
                labelCol: { span: 4 },
                wrapperCol: { span: 20 }
            };
            var formItemLayout = ["vertical", "inline"].includes(layout) ? {} : DEFAULT_FORMITEM_LAYOUT;
            var renderItem = function renderItem(_a, i) {
                var _a$visible = _a.visible,
                    visible = _a$visible === undefined ? true : _a$visible,
                    _a$itemSpan = _a.itemSpan,
                    itemSpan = _a$itemSpan === undefined ? 8 : _a$itemSpan,
                    decorate = _a.decorate,
                    _a$id = _a.id,
                    id = _a$id === undefined ? "r-form-item-uuid" : _a$id,
                    decoratorOptions = _a.decoratorOptions,
                    control = _a.control,
                    rest = __rest(_a, ["visible", "itemSpan", "decorate", "id", "decoratorOptions", "control"]);

                if (!visible) {
                    return null;
                }
                var formItemControl = control;
                if (formItemControl && typeof formItemControl.type === "function" && !formItemControl.props.size) {
                    formItemControl = React.cloneElement(formItemControl, {
                        size: "default"
                    });
                }
                if (decorate) formItemControl = getFieldDecorator(id, decoratorOptions)(formItemControl);
                return React.createElement(
                    Col,
                    { key: i, span: itemSpan },
                    React.createElement(
                        FormItem,
                        _extends({}, formItemLayout, rest),
                        formItemControl
                    )
                );
            };
            var formItemsToRender = formItems;
            if (renderCount) formItemsToRender = formItems.slice(0, renderCount);
            return formItemsToRender.map(renderItem);
        };
        _this.onPreAdvancedToggle = function () {
            var _this$props3 = _this.props,
                _this$props3$defaultR = _this$props3.defaultRenderFormItemCount,
                defaultRenderFormItemCount = _this$props3$defaultR === undefined ? 0 : _this$props3$defaultR,
                renderFormItemCount = _this$props3.renderFormItemCount,
                _this$props3$footer = _this$props3.footer,
                footer = _this$props3$footer === undefined ? {} : _this$props3$footer;
            var onAdvancedToggle = footer.onAdvancedToggle;
            var _this$state$renderCou = _this.state.renderCount,
                renderCount = _this$state$renderCou === undefined ? 0 : _this$state$renderCou;

            if (typeof renderFormItemCount == "number" && typeof onAdvancedToggle == "function") {
                return onAdvancedToggle(renderCount);
            }
            var nextRenderCount = !renderCount ? defaultRenderFormItemCount : 0;
            _this.setState({ renderCount: nextRenderCount });
        };
        _this.renderFooter = function () {
            var _this$props$footer2 = _this.props.footer,
                footer = _this$props$footer2 === undefined ? false : _this$props$footer2;

            if (!footer) return null;
            var _this$state$renderCou2 = _this.state.renderCount,
                renderCount = _this$state$renderCou2 === undefined ? 0 : _this$state$renderCou2;
            var _footer$defaultAction = footer.defaultActionAlign,
                defaultActionAlign = _footer$defaultAction === undefined ? "left" : _footer$defaultAction,
                _footer$defaultAction2 = footer.defaultActionSpan,
                defaultActionSpan = _footer$defaultAction2 === undefined ? 24 : _footer$defaultAction2,
                extraAction = footer.extraAction,
                _footer$showClear = footer.showClear,
                showClear = _footer$showClear === undefined ? false : _footer$showClear,
                _footer$clearText = footer.clearText,
                clearText = _footer$clearText === undefined ? "Clear" : _footer$clearText,
                _footer$submitText = footer.submitText,
                submitText = _footer$submitText === undefined ? "Submit" : _footer$submitText,
                _footer$submitDisable = footer.submitDisabled,
                submitDisabled = _footer$submitDisable === undefined ? false : _footer$submitDisable,
                _footer$submitExtraPr = footer.submitExtraProps,
                submitExtraProps = _footer$submitExtraPr === undefined ? {} : _footer$submitExtraPr,
                _footer$showAdvancedT = footer.showAdvancedToggle,
                showAdvancedToggle = _footer$showAdvancedT === undefined ? false : _footer$showAdvancedT,
                _footer$advancedToggl = footer.advancedToggleTexts,
                advancedToggleTexts = _footer$advancedToggl === undefined ? ["Expand", "Collapse"] : _footer$advancedToggl,
                onSubmit = footer.onSubmit;

            var renderExtra = function renderExtra() {
                if (!extraAction) return null;
                return React.createElement(
                    Col,
                    { span: 24 - Number(defaultActionSpan) },
                    extraAction
                );
            };
            var renderAdvancedToggle = function renderAdvancedToggle() {
                if (!showAdvancedToggle) return null;
                var text = !renderCount ? advancedToggleTexts[1] : advancedToggleTexts[0];
                return React.createElement(
                    "a",
                    { style: { marginRight: 4 }, onClick: _this.onPreAdvancedToggle },
                    text
                );
            };
            var renderClear = function renderClear() {
                if (!showClear) return null;
                return React.createElement(
                    Button,
                    { style: { marginRight: 4 }, onClick: _this.onPreClear },
                    clearText
                );
            };
            return React.createElement(
                Row,
                null,
                renderExtra(),
                React.createElement(
                    Col,
                    { style: { textAlign: defaultActionAlign }, span: Number(defaultActionSpan) },
                    renderAdvancedToggle(),
                    renderClear(),
                    React.createElement(
                        Button,
                        _extends({ type: "primary", disabled: submitDisabled }, submitExtraProps, { onClick: onSubmit }),
                        submitText
                    )
                )
            );
        };
        var getRenderCount = function getRenderCount(_ref) {
            var _ref$defaultRenderFor = _ref.defaultRenderFormItemCount,
                defaultRenderFormItemCount = _ref$defaultRenderFor === undefined ? 0 : _ref$defaultRenderFor,
                renderFormItemCount = _ref.renderFormItemCount;

            if (typeof renderFormItemCount == "number") return renderFormItemCount;
            return defaultRenderFormItemCount;
        };
        _this.state = {
            renderCount: getRenderCount(props)
        };
        return _this;
    }

    _createClass(RForm, [{
        key: "componentWillReceiveProps",
        value: function componentWillReceiveProps(_ref2) {
            var renderFormItemCount = _ref2.renderFormItemCount;

            if (typeof renderFormItemCount == "number" && this.props.renderFormItemCount !== renderFormItemCount && this.state.renderCount !== renderFormItemCount) {
                this.setState({ renderCount: renderFormItemCount });
            }
        }
    }, {
        key: "render",
        value: function render() {
            var _a = this.props,
                _a$formItemGutter = _a.formItemGutter,
                formItemGutter = _a$formItemGutter === undefined ? 10 : _a$formItemGutter,
                background = _a.background,
                others = __rest(_a, ["formItemGutter", "background"]);
            var clazz = classNames({
                "r-antd-r-form_background--normal": background === "normal"
            });
            var rest = omit(others, ["form", "wrappedComponentRef", "header", "formItems", "defaultRenderFormItemCount", "renderFormItemCount", "footer", "onFormChange", "onValuesChange"]);
            return React.createElement(
                Form,
                _extends({ className: clazz }, rest),
                this.renderHeader(),
                React.createElement(
                    Row,
                    { gutter: formItemGutter },
                    this.renderFormItems()
                ),
                this.renderFooter()
            );
        }
    }]);

    return RForm;
}(Component);
RForm.defaultProps = {
    formItemGutter: 10,
    defaultRenderFormItemCount: 0
};
var WrappedForm = Form.create({
    onFieldsChange: function onFieldsChange(_ref3, changedFields) {
        var onFormChange = _ref3.onFormChange;

        if (typeof onFormChange != "function") return;
        onFormChange(changedFields);
    },
    onValuesChange: function onValuesChange(_ref4, values) {
        var _onValuesChange = _ref4.onValuesChange;

        if ((typeof values === "undefined" ? "undefined" : _typeof(values)) != "object") return;

        var _Object$entries = Object.entries(values),
            _Object$entries2 = _slicedToArray(_Object$entries, 1),
            first = _Object$entries2[0];

        if (typeof _onValuesChange != "function") return;
        _onValuesChange(first, values);
    }
})(RForm);
export default WrappedForm;

==> r-antd-0.2.10.tgz: package/es/r-form/r-form.js <==
import _slicedToArray from "babel-runtime/helpers/slicedToArray";
import _typeof from "babel-runtime/helpers/typeof";
import _extends from "babel-runtime/helpers/extends";
import _classCallCheck from "babel-runtime/helpers/classCallCheck";
import _createClass from "babel-runtime/helpers/createClass";
import _possibleConstructorReturn from "babel-runtime/helpers/possibleConstructorReturn";
import _inherits from "babel-runtime/helpers/inherits";
var __rest = this && this.__rest || function (s, e) {
    var t = {};
    for (var p in s) {
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
    }if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
        if (e.indexOf(p[i]) < 0) t[p[i]] = s[p[i]];
    }return t;
};
import React, { Component } from "react";
import classNames from "classnames";
import omit from "lodash.omit";
import { Row, Col, Form, Button, Icon } from "antd";
var FormItem = Form.Item;

export var RForm = function (_Component) {
    _inherits(RForm, _Component);

    function RForm(props) {
        _classCallCheck(this, RForm);

        var _this = _possibleConstructorReturn(this, (RForm.__proto__ || Object.getPrototypeOf(RForm)).call(this, props));

        _this.onPreClear = function () {
            var _this$props = _this.props,
                form = _this$props.form,
                _this$props$footer = _this$props.footer,
                footer = _this$props$footer === undefined ? {} : _this$props$footer;
            var resetFields = form.resetFields;

            resetFields();
            var onClear = footer.onClear;

            if (typeof onClear != "function") return;
            onClear();
        };
        _this.renderHeader = function () {
            var header = _this.props.header;

            if (!header) return null;
            return React.createElement(
                Row,
                { style: { marginBottom: 24 } },
                React.createElement(
                    Col,
                    { span: 24 },
                    header
                )
            );
        };
        _this.renderFormItems = function () {
            var _this$props2 = _this.props,
                form = _this$props2.form,
                formItems = _this$props2.formItems,
                _this$props2$layout = _this$props2.layout,
                layout = _this$props2$layout === undefined ? "horizontal" : _this$props2$layout;
            var getFieldDecorator = form.getFieldDecorator;
            var renderCount = _this.state.renderCount;

            var DEFAULT_FORMITEM_LAYOUT = {
                labelCol: { span: 4 },
                wrapperCol: { span: 20 }
            };
            var formItemLayout = ["vertical", "inline"].includes(layout) ? {} : DEFAULT_FORMITEM_LAYOUT;
            var renderItem = function renderItem(_a, i) {
                var _a$visible = _a.visible,
                    visible = _a$visible === undefined ? true : _a$visible,
                    _a$itemSpan = _a.itemSpan,
                    itemSpan = _a$itemSpan === undefined ? 8 : _a$itemSpan,
                    decorate = _a.decorate,
                    _a$id = _a.id,
                    id = _a$id === undefined ? "r-form-item-uuid" : _a$id,
                    decoratorOptions = _a.decoratorOptions,
                    control = _a.control,
                    rest = __rest(_a, ["visible", "itemSpan", "decorate", "id", "decoratorOptions", "control"]);

                if (!visible) {
                    return null;
                }
                var formItemControl = control;
                if (formItemControl && typeof formItemControl.type === "function" && !formItemControl.props.size) {
                    formItemControl = React.cloneElement(formItemControl, {
                        size: "default"
                    });
                }
                if (decorate) formItemControl = getFieldDecorator(id, decoratorOptions)(formItemControl);
                return React.createElement(
                    Col,
                    { key: i, span: itemSpan },
                    React.createElement(
                        FormItem,
                        _extends({}, formItemLayout, rest),
                        formItemControl
                    )
                );
            };
            var formItemsToRender = formItems;
            if (renderCount) formItemsToRender = formItems.slice(0, renderCount);
            return formItemsToRender.map(renderItem);
        };
        _this.onPreAdvancedToggle = function () {
            var _this$props3 = _this.props,
                _this$props3$defaultR = _this$props3.defaultRenderFormItemCount,
                defaultRenderFormItemCount = _this$props3$defaultR === undefined ? 0 : _this$props3$defaultR,
                renderFormItemCount = _this$props3.renderFormItemCount,
                _this$props3$footer = _this$props3.footer,
                footer = _this$props3$footer === undefined ? {} : _this$props3$footer;
            var onAdvancedToggle = footer.onAdvancedToggle;
            var _this$state$renderCou = _this.state.renderCount,
                renderCount = _this$state$renderCou === undefined ? 0 : _this$state$renderCou;

            if (typeof renderFormItemCount == "number" && typeof onAdvancedToggle == "function") {
                return onAdvancedToggle(renderCount);
            }
            var nextRenderCount = !renderCount ? defaultRenderFormItemCount : 0;
            _this.setState({ renderCount: nextRenderCount });
        };
        _this.renderFooter = function () {
            var _this$props$footer2 = _this.props.footer,
                footer = _this$props$footer2 === undefined ? false : _this$props$footer2;

            if (!footer) return null;
            var _this$state$renderCou2 = _this.state.renderCount,
                renderCount = _this$state$renderCou2 === undefined ? 0 : _this$state$renderCou2;
            var _footer$defaultAction = footer.defaultActionAlign,
                defaultActionAlign = _footer$defaultAction === undefined ? "left" : _footer$defaultAction,
                _footer$defaultAction2 = footer.defaultActionSpan,
                defaultActionSpan = _footer$defaultAction2 === undefined ? 24 : _footer$defaultAction2,
                _footer$defaultAction3 = footer.defaultActionOffset,
                defaultActionOffset = _footer$defaultAction3 === undefined ? 0 : _footer$defaultAction3,
                extraAction = footer.extraAction,
                _footer$showClear = footer.showClear,
                showClear = _footer$showClear === undefined ? false : _footer$showClear,
                _footer$clearText = footer.clearText,
                clearText = _footer$clearText === undefined ? "Clear" : _footer$clearText,
                _footer$submitText = footer.submitText,
                submitText = _footer$submitText === undefined ? "Submit" : _footer$submitText,
                _footer$submitDisable = footer.submitDisabled,
                submitDisabled = _footer$submitDisable === undefined ? false : _footer$submitDisable,
                _footer$submitExtraPr = footer.submitExtraProps,
                submitExtraProps = _footer$submitExtraPr === undefined ? {} : _footer$submitExtraPr,
                _footer$showAdvancedT = footer.showAdvancedToggle,
                showAdvancedToggle = _footer$showAdvancedT === undefined ? false : _footer$showAdvancedT,
                _footer$advancedToggl = footer.advancedToggleTexts,
                advancedToggleTexts = _footer$advancedToggl === undefined ? ["Expand", "Collapse"] : _footer$advancedToggl,
                onSubmit = footer.onSubmit;

            var renderExtra = function renderExtra() {
                if (!extraAction) return null;
                return React.createElement(
                    Col,
                    { span: 24 - Number(defaultActionSpan) },
                    extraAction
                );
            };
            var renderAdvancedToggle = function renderAdvancedToggle() {
                if (!showAdvancedToggle) return null;
                var text = !renderCount ? advancedToggleTexts[1] : advancedToggleTexts[0];
                var iconType = !renderCount ? "up" : "down";
                return React.createElement(
                    "a",
                    { style: { letterSpacing: 2 }, onClick: _this.onPreAdvancedToggle },
                    text,
                    " ",
                    React.createElement(Icon, { type: iconType })
                );
            };
            var renderClear = function renderClear() {
                if (!showClear) return null;
                return React.createElement(
                    Button,
                    { style: { marginRight: 8 }, onClick: _this.onPreClear },
                    clearText
                );
            };
            return React.createElement(
                Row,
                null,
                renderExtra(),
                React.createElement(
                    Col,
                    { style: { textAlign: defaultActionAlign }, span: Number(defaultActionSpan), offset: Number(defaultActionOffset) },
                    renderClear(),
                    React.createElement(
                        Button,
                        _extends({ type: "primary", disabled: submitDisabled }, submitExtraProps, { onClick: onSubmit }),
                        submitText
                    )
                ),
                React.createElement(
                    Col,
                    { span: 24, style: { textAlign: "center" } },
                    renderAdvancedToggle()
                )
            );
        };
        var getRenderCount = function getRenderCount(_ref) {
            var _ref$defaultRenderFor = _ref.defaultRenderFormItemCount,
                defaultRenderFormItemCount = _ref$defaultRenderFor === undefined ? 0 : _ref$defaultRenderFor,
                renderFormItemCount = _ref.renderFormItemCount;

            if (typeof renderFormItemCount == "number") return renderFormItemCount;
            return defaultRenderFormItemCount;
        };
        _this.state = {
            renderCount: getRenderCount(props)
        };
        return _this;
    }

    _createClass(RForm, [{
        key: "componentWillReceiveProps",
        value: function componentWillReceiveProps(_ref2) {
            var renderFormItemCount = _ref2.renderFormItemCount;

            if (typeof renderFormItemCount == "number" && this.props.renderFormItemCount !== renderFormItemCount && this.state.renderCount !== renderFormItemCount) {
                this.setState({ renderCount: renderFormItemCount });
            }
        }
    }, {
        key: "render",
        value: function render() {
            var _a = this.props,
                _a$formItemGutter = _a.formItemGutter,
                formItemGutter = _a$formItemGutter === undefined ? 10 : _a$formItemGutter,
                background = _a.background,
                others = __rest(_a, ["formItemGutter", "background"]);
            var clazz = classNames({
                "r-antd-r-form_background--normal": background === "normal"
            });
            var rest = omit(others, ["form", "wrappedComponentRef", "header", "formItems", "defaultRenderFormItemCount", "renderFormItemCount", "footer", "onFormChange", "onValuesChange"]);
            return React.createElement(
                Form,
                _extends({ className: clazz }, rest),
                this.renderHeader(),
                React.createElement(
                    Row,
                    { gutter: formItemGutter },
                    this.renderFormItems()
                ),
                this.renderFooter()
            );
        }
    }]);

    return RForm;
}(Component);
RForm.defaultProps = {
    formItemGutter: 10,
    defaultRenderFormItemCount: 0
};
var WrappedForm = Form.create({
    onFieldsChange: function onFieldsChange(_ref3, changedFields) {
        var onFormChange = _ref3.onFormChange;

        if (typeof onFormChange != "function") return;
        onFormChange(changedFields);
    },
    onValuesChange: function onValuesChange(_ref4, values) {
        var _onValuesChange = _ref4.onValuesChange;

        if ((typeof values === "undefined" ? "undefined" : _typeof(values)) != "object") return;

        var _Object$entries = Object.entries(values),
            _Object$entries2 = _slicedToArray(_Object$entries, 1),
            first = _Object$entries2[0];

        if (typeof _onValuesChange != "function") return;
        _onValuesChange(first, values);
    }
})(RForm);
export default WrappedForm;
